
#ifndef _C13_ds613_
#define _C13_ds613_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1023_6781(EIF_REFERENCE);
extern void EIF_Minit613(void);
extern char *(*R5673[])();

#ifdef __cplusplus
}
#endif

#endif
